@@ -2,11 +2,17 @@ from dataclasses import dataclass
 from typing import Dict, Optional
 
 
-@dataclass
 class NetworkConfig:
-    graph_url: str
-    contracts: Dict[str, str]
-    is_testnet: bool = False
+    def __init__(
+        self,
+        graph_url: str,
+        contracts: Dict[str, str],
+        is_testnet: bool
+    ):
+        self.graph_url = graph_url
+        self.contracts = contracts
+        self.is_testnet = is_testnet
+        self.network = "testnet" if is_testnet else "mainnet"
 
     @classmethod
     def mainnet(cls) -> 'NetworkConfig':
